<?php

namespace SplitTestForElementor\Admin\Classes\Repo;

use SplitTestForElementor\Classes\Repo\TestManager;
use SplitTestForElementor\Libs\Carbon\Carbon;

class StatisticsRepo {

	// LOW@kberlau Runs only under mysql???

	public function getStats($testId, $startDate = null, $endDate = null) {

		if ($startDate == null) {
			$startDate = Carbon::now()->subDays(90);
		} else if (!$startDate instanceof Carbon) {
			$startDate = Carbon::parse($startDate);
		}
		if ($endDate == null) {
			$endDate = Carbon::now();
		} else if (!$startDate instanceof Carbon) {
			$endDate = Carbon::parse($endDate);
		}

		global $wpdb;

		$testManager = new TestManager();
		$variations = $testManager->getVariations($testId);
		$variationsById = [];

		foreach ($variations as $key => $variation) {
			$variation->stats = $this->generateEmptyStats($startDate, $endDate);
			$variationsById[$variation->id] = $variation;
		}

		if (!filter_var($testId, FILTER_VALIDATE_INT)) {
			// LOW@kberlau Log / Show error
			return $variations;
		}

		// LOW use prepared statement
		$query = [];
		$query[] = "SELECT COUNT(*) as count, type, variation_id, created_at";
		$query[] = "FROM ".$wpdb->prefix."elementor_splittest_interactions";
		$query[] = "WHERE splittest_id = ".$testId." GROUP BY type, variation_id, (YEAR(created_at) + MONTH(created_at) + DAY(created_at))";
		$query[] = "ORDER BY variation_id, created_at";

		$results = $wpdb->get_results(implode(" ", $query));

		foreach ($results as $result) {
			/** @var Carbon $date */
			$date = Carbon::parse($result->created_at);
			if (!isset($variationsById[$result->variation_id])) {
				continue;
			}
			$variation = $variationsById[$result->variation_id];

			if ($result->type == "view") {
				$variation->stats['dates'][$date->toDateString()]['views'] += (int) $result->count;
				$variation->stats['allViews'] += (int) $result->count;
			} else if ($result->type == "conversion") {
				$variation->stats['dates'][$date->toDateString()]['views'] += (int) $result->count;
				$variation->stats['allViews'] += (int) $result->count;
				$variation->stats['dates'][$date->toDateString()]['conversions'] += (int) $result->count;
				$variation->stats['allConversions'] += (int) $result->count;
			}
		}

		return $variations;
	}

	private function generateEmptyStats(Carbon $startDate, Carbon $endDate) {

		/** @var Carbon $calcDate */
		$calcDate = $startDate->copy();
		$calcDate->subDay();

		$stats = ['allViews' => 0, 'allConversions' => 0];

		while($calcDate->diffInDays($endDate) > 0) {
			$calcDate->addDay();
			$stats['dates'][$calcDate->toDateString()] = ['views' => 0, 'conversions' => 0];
		}

		return $stats;

	}

}