<?php

namespace SplitTestForElementor\Classes\Repo;

class TestManager {

	public function getAllTests($withInActive = false, $withDeleted = false) {
		global $wpdb;

		$query = [];
		$query[] = "SELECT * FROM ".$this->getTestTable();
		if (!$withInActive) {
			$query[] = "WHERE ".$this->getTestTable().".active IS TRUE";
		}

		$tests = $wpdb->get_results(implode(" ", $query), OBJECT);

		for ($i = 0; $i < sizeof($tests); $i++) {
			$tests[$i]->variations = $this->getVariations($tests[$i]->id, $withInActive, $withDeleted);
		}

		return $tests;
	}

	public function getTest($testId, $withInActive = false, $withDeleted = false) {
		$tests = $this->getTests([$testId], $withInActive, $withDeleted);
		return sizeof($tests) > 0 ? $tests[0] : null;
	}

	public function getTests($ids, $withInActive = false, $withDeleted = false) {
		if (sizeof($ids) == 0) {
			return [];
		}

		global $wpdb;
		$tests = $wpdb->get_results("SELECT * FROM ".$this->getTestTable()." WHERE id IN(".implode(",", $ids).")", OBJECT);

		for ($i = 0; $i < sizeof($tests); $i++) {
			$tests[$i]->variations = $this->getVariations($tests[$i]->id, $withInActive, $withDeleted);
		}

		return $tests;
	}

	public function getTestsByConversionPagePostId($postId) {
		global $wpdb;
		$tests = $wpdb->get_results("SELECT * FROM ".$this->getTestTable()." WHERE conversion_page_id = '".$postId."'", OBJECT);

		for ($i = 0; $i < sizeof($tests); $i++) {
			$tests[$i]->variations = $this->getVariations($tests[$i]->id, false, false);
		}

		return $tests;
	}

	public function getRedirectTestsByUri($uri) {
		global $wpdb;
		$tests = $wpdb->get_results("SELECT * FROM ".$this->getTestTable()." WHERE test_uri = '".$uri."'", OBJECT);

		for ($i = 0; $i < sizeof($tests); $i++) {
			$tests[$i]->variations = $this->getVariations($tests[$i]->id, false, false);
		}

		return $tests;
	}

	public function getVariations($postId, $withInActive = false, $withDeleted = false) {
		global $wpdb;

		$query = [];
		$query[] = "SELECT * FROM ".$this->getVariationTable();
		if (!$withInActive && !$withDeleted) {
			$query[] = "WHERE ".$this->getVariationTable().".active IS TRUE";
			$query[] = "AND ".$this->getVariationTable().".deleted_at IS NULL";
			$query[] = "AND splittest_id = ".$postId;
		} else if (!$withInActive && $withDeleted) {
			$query[] = "WHERE ".$this->getVariationTable().".active IS TRUE";
			$query[] = "AND splittest_id = ".$postId;
		} else if ($withInActive && !$withDeleted) {
			$query[] = "WHERE ".$this->getVariationTable().".deleted_at IS NULL";
			$query[] = "AND splittest_id = ".$postId;
		} else {
			$query[] = "WHERE splittest_id = ".$postId;
		}

		$results = $wpdb->get_results(implode(" ", $query), OBJECT);
		foreach ($results as $result) {
			$result->post_id = (int) $result->post_id;
		}

		return $results;
	}

	public function updateTest($id, $data) {
		global $wpdb;

		$wpdb->update($this->getTestTable(), [
			'name' => $data['name'],
			'test_type' => $data['testType'],
			'test_uri' => $data['testType'] == "pages" ? $data['testUri'] : null,
			'conversion_type' => $data['conversionType'],
			'conversion_page_id' => $data['conversionPageId']
		], ['id' => $id], ['%s', '%s', '%s'], ['%d']);
	}

	public function createTest($data) {
		global $wpdb;
		$result = $wpdb->insert($this->getTestTable(), array(
			'name' => $data['name'],
			'active' => true,
			'test_type' => $data['testType'],
			'test_uri' => $data['testType'] == "pages" ? $data['testUri'] : null,
			'conversion_type' => $data['conversionType'],
			'conversion_page_id' => $data['conversionPageId'],
			'created_at' => current_time('mysql')
		), array('%s'));
		return $wpdb->insert_id;
	}

	public function deleteTest($id) {
		global $wpdb;
		$test = $this->getTest($id, true, true);
		if ($test == null) {
			return;
		}
		if (sizeof($test->variations) > 0) {
			foreach ($test->variations as $variation) {
				$this->deleteTestVariation($variation->id);
			}
		}
		$postTestRepo = new PostTestRepo();
		$postTestRepo->deletePostTestByTestId($test->id);
		$this->deleteTestInteractions($test->id);
		$wpdb->delete($this->getTestTable(), ['id' => $id], ['%d']);
	}

	public function deleteTestInteractions($splitTestID) {
		global $wpdb;
		$wpdb->delete($this->getTestIntetractionsTable(), ['splittest_id' => $splitTestID], ['%d']);
	}

	public function createTestVariation($testId, $data) {
		global $wpdb;
		$result = $wpdb->insert($this->getVariationTable(), array(
			'name' => $data['name'],
			'percentage' => (int) $data['percentage'],
			'post_id' => isset($data['postId']) ? (int) $data['postId'] : null,
			'splittest_id' => $testId,
			'active' => true,
			'created_at' => current_time('mysql')
		), array('%s', '%d', '%d', '%d'));
		return $wpdb->insert_id;
	}

	public function updateTestVariation($id, $data) {
		global $wpdb;
		$wpdb->update($this->getVariationTable(),
			['name' => $data['name'], 'percentage' => (int) $data['percentage'], 'post_id' => $data['postId']],
			['id' => $id],
			['%s', '%d'], ['%d']
		);
	}

	public function softDeleteTestVariation($id) {
		global $wpdb;
		$wpdb->update($this->getVariationTable(),
			['deleted_at' => current_time( 'mysql' )],
			['id' => $id],
			['%s'],
			['%d']
		);
	}

	public function deleteTestVariation($id) {
		global $wpdb;
		$wpdb->delete($this->getVariationTable(), ['id' => $id], ['%d']);
	}

	private function getTestTable() {
		global $wpdb;
		return $wpdb->prefix.'elementor_splittest';
	}

	private function getVariationTable() {
		global $wpdb;
		return $wpdb->prefix.'elementor_splittest_variations';
	}

	private function getTestIntetractionsTable() {
		global $wpdb;
		return $wpdb->prefix.'elementor_splittest_interactions';
	}



}