<?php

namespace SplitTestForElementor\Classes\Services;

use Elementor\Plugin;
use SplitTestForElementor\Classes\Misc\SettingsManager;
use SplitTestForElementor\Classes\Repo\TestManager;

class CacheBuster
{

	private static $settingsManager;

	/**
	 * WidgetRenderContentEvent constructor.
	 */
	public function __construct() {
		if (self::$settingsManager == null) {
			self::$settingsManager = new SettingsManager();
		}
	}

	public function renderContent($content, $element) {
		if (Plugin::$instance->editor->is_edit_mode()) {
			return $content;
		}

		global $targetVariations;
		$testManager = new TestManager();

		$testId = $element->get_settings('split_test_control_test_id');
		if (!filter_var($testId, FILTER_VALIDATE_INT) || $testId == null) {
			return $content;
		}
		$variationId = $element->get_settings('split_test_control_variation_id');
		$test = $testManager->getTest($testId);
		if ($test == null) {
			return $content;
		}

		$targetVariation = $targetVariations[$test->id];
		if (self::$settingsManager->getRawValue(SettingsManager::CACHE_BUSTER_ACTIVE)) {
			$placeholderId = "rocket-test-placeholder-".rand(10000000, 99999999)."-".$element->get_id();
			ob_start();
			?>
			<div id="<?php echo ($placeholderId); ?>"></div>
			<script type="text/javascript">
				var content = decodeURIComponent(('<?php echo urlencode(str_replace(array("\r", "\n", "\t"), '', $content)); ?>').replace(/\+/g, " "));
				if (!window.window.rocketSplitTest.isActiveVariation(<?php echo($testId); ?>, <?php echo($variationId); ?>)) {
					content = "";
				}
				document.getElementById("<?php echo($placeholderId); ?>").parentElement.innerHTML = content;
			</script>
			<?php
			$content = ob_get_contents();
			ob_end_clean();
		} else {
			foreach ($test->variations as $variation) {
				if ($variation->id != $targetVariation->id && $variation->id == $variationId) {
					return "";
				}
			}
		}

		return $content;
	}

}