<?php

use SplitTestForElementor\Admin\Classes\Controllers\SplitTestController;
use SplitTestForElementor\Admin\Classes\Controllers\StatisticsController;
use SplitTestForElementor\Admin\Classes\Elementor\ConversionWidget;
use SplitTestForElementor\Admin\Classes\Events\AdminInitEvent;
use SplitTestForElementor\Admin\Classes\Events\AfterSectionEndEvent;
use SplitTestForElementor\Classes\Endpoints\TestController;
use SplitTestForElementor\Classes\Endpoints\VariationController;
use SplitTestForElementor\Classes\Events\FrontendBeforeRenderEvent;
use SplitTestForElementor\Classes\Events\SendHeadersEvent;
use SplitTestForElementor\Classes\Events\WidgetRenderContentEvent;
use SplitTestForElementor\Classes\Events\WpHeaderEvent;
use SplitTestForElementor\Classes\Events\SectionShouldRenderEvent;
use SplitTestForElementor\Classes\Install\DB;
use SplitTestForElementor\Classes\Repo\PostTestManager;
use SplitTestForElementor\Classes\Services\SettingsPage;
use SplitTestForElementor\Classes\Update\UpdateManager;
use SplitTestForElementor\Classes\Services\CustomUrlService;

/**
 * @package SplitTestForElementor
 * @version 1.3.5
 * @copyright Copyright (C) 2018 Rocket Elements
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License, version 3 or higher

 * Plugin Name: Split Test For Elementor
 * Plugin URI: https://wordpress.org/plugins/split-test-for-elementor/
 * Description: Split Test For Elementor
 * Author: Rocket Elements
 * Version: 1.3.5
 * Author URI: https://www.rocketelements.io
 * License:     GPL v3
 * Text Domain: split-test-for-elementor
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

define('SPLIT_TEST_FOR_ELEMENTOR_MAIN_FILE', __FILE__);
define('SPLIT_TEST_FOR_ELEMENTOR_VERSION', "1.3.5");
define('SPLIT_TEST_FOR_ELEMENTOR_VERSION_OPTION_NAME', "split_test_for_elementor_version");
define('SPLIT_TEST_FOR_ELEMENTOR_PRO_VERSION_LINK', 'https://www.rocketelements.io/splittest-pro/');
define('SPLIT_TEST_FOR_ELEMENTOR_LITE_MAX_TEST_COUNT', 5);
define('SPLIT_TEST_FOR_ELEMENTOR_LITE_MAX_VARIATION_COUNT', 2);
define('SPLIT_TEST_FOR_ELEMENTOR_SUPPORT_LINK', 'https://www.rocketelements.io/support/');

require_once(__DIR__."/vendor/autoload.php");

// Updates and Setup ===================================================================================================

// Setup Database
register_activation_hook(__FILE__, array(new DB(), 'setup'));

// Updates
add_action('plugins_loaded', function() {
	if (is_admin()) {
		UpdateManager::runUpdates();
	}
});

// =====================================================================================================================

add_action('elementor/widgets/widgets_registered', function(\Elementor\Widgets_Manager $widgets_manager) {
	$widgets_manager->register_widget_type(new ConversionWidget());
});

// Decide witch test variation to show and tracks conversions
add_action('send_headers', array(new SendHeadersEvent(), 'fire'));

add_action('wp_head', array(new WpHeaderEvent(), 'fire'));

// Adding css for hiding / showing split test elements
add_action('elementor/frontend/section/before_render', [new FrontendBeforeRenderEvent(), 'fire']);
// Removing widgets from content from output
add_action('elementor/widget/render_content', [new WidgetRenderContentEvent(), 'fire'], 10, 2);

$sectionShouldRenderEvent = new SectionShouldRenderEvent();
add_action('elementor/frontend/section/should_render', [$sectionShouldRenderEvent, 'fire'], 10, 2);

// Admin ===============================================================================================================

function splittest_for_elementor_page() {
	add_menu_page(
		'Split test for Elementor',
		'Split test',
		'manage_options',
		'splittest-for-elementor',
		'splittest_for_elementor_page_html',
		plugin_dir_url(__FILE__) . 'Admin/assets/images/icon.png',
		20
	);
}
add_action('admin_menu', 'splittest_for_elementor_page');

// Registering controllers before content is send
add_action('admin_init', array(new AdminInitEvent(), 'fire'));
function splittest_for_elementor_page_html() {
	switch (isset($_GET['scope']) ? $_GET['scope'] : "test") {
		case "test"         : (new SplitTestController())->run(); break;
		case "statistics"   : (new StatisticsController())->run(); break;
		default             : break;
	}
}

add_action('elementor/editor/before_enqueue_scripts', function() {
	wp_enqueue_script(
		'split-test-for-elementor-editor',
		plugins_url('Admin/assets/js/editor.min.js', SPLIT_TEST_FOR_ELEMENTOR_MAIN_FILE),
		[],
		SPLIT_TEST_FOR_ELEMENTOR_VERSION,
		true // in_footer
	);
});

// Rest Endpoints ======================================================================================================
add_action('rest_api_init', function () {
	register_rest_route( 'splitTestForElementor/v1', '/tests/', [
		'methods' => 'POST',
		'callback' => array(new TestController(), 'store')
	]);
});

add_action('rest_api_init', function () {
	register_rest_route( 'splitTestForElementor/v1', '/variations/', [
		'methods' => 'POST',
		'callback' => array(new VariationController(), 'store')
	]);
});

// Editor ==============================================================================================================

// Add Split test controls to editor
add_action('elementor/element/after_section_end', [new AfterSectionEndEvent(), 'fire'], 10, 3);

// Synchronize split tests / posts connections after save
add_action('elementor/editor/after_save', [new PostTestManager(), 'onEditorSave'], 10, 3);

do_action('split_test_for_elementor_after_init');

add_action( 'plugins_loaded', function() {
	load_plugin_textdomain( 'split-test-for-elementor' );
} );

// Other startup stuff
(new CustomUrlService)->registerHooks();

(new SettingsPage)->registerSettingsPage();

add_action('elementor/frontend/section/after_render', [new \SplitTestForElementor\Classes\Events\FrontendAfterRenderSectionEvent(), 'fire']);

/*
add_action( 'wp_footer', function() {
	if ( ! defined( 'ELEMENTOR_VERSION' ) ) {
		return;
	}
	?>
	<script>
		jQuery( function( $ ) {
			// Add space for Elementor Menu Anchor link
			if ( window.elementorFrontend ) {
				jQuery(document).ready(function () {
					elementor.hooks.addAction( 'panel/open_editor/widget', function( panel, model, view ) {
						console.log("init split test "  + view);
						// console.log(window);
						document.splitTestForElementor.init();	
					});
					jQuery(".elementor-tab-control-advanced").click(function () {
						console.log("est");
					});
				});
			}
		} );
	</script>
	<?php
} );
*/
